﻿namespace NetinaShop.Core.EntityServices.DiscountHandlers;

public class CalculateOrderDiscountCommandHandler : IRequestHandler<CalculateOrderDiscountCommand , double>
{
    private readonly IRepositoryWrapper _repositoryWrapper;

    public CalculateOrderDiscountCommandHandler(IRepositoryWrapper repositoryWrapper)
    {
        _repositoryWrapper = repositoryWrapper;
    }
    public async Task<double> Handle(CalculateOrderDiscountCommand request, CancellationToken cancellationToken)
    {
        if (request.Order == null)
            throw new AppException("Order is null", ApiResultStatusCode.BadRequest);

        var discount = await _repositoryWrapper.SetRepository<Discount>()
            .TableNoTracking
            .FirstOrDefaultAsync(d => d.Code == request.DiscountCode, cancellationToken);

        if (discount == null)
            throw new AppException("تخفیف وجود منقضی شده است یا وجود ندارد", ApiResultStatusCode.NotFound);

        double discountPrice = 0;
        double totalPrice = 0;
        if (discount.Type == DiscountType.All)
        {
            if (!discount.IsExpired())
            {
                totalPrice = request.Order.OrderProducts.Sum(op => op.ProductCost);
            }
        }
        else if (discount.Type == DiscountType.Category)
        {
            var categoryDiscount = await _repositoryWrapper.SetRepository<CategoryDiscount>()
                .TableNoTracking
                .FirstOrDefaultAsync(d => d.Code == request.DiscountCode, cancellationToken);
            if ( categoryDiscount!=null && !categoryDiscount.IsExpired())
            {
                totalPrice = request.Order.OrderProducts.Where(op => op.ProductCategoryId == categoryDiscount.CategoryId).Sum(op => op.ProductCost);

            }
        }
        else if (discount.Type == DiscountType.Product)
        {
            var productDiscount = await _repositoryWrapper.SetRepository<ProductDiscount>()
                .TableNoTracking
                .FirstOrDefaultAsync(d => d.Code == request.DiscountCode, cancellationToken);

            if (productDiscount != null && !productDiscount.IsExpired())
            {
                totalPrice = request.Order.OrderProducts.Where(op => op.ProductId == productDiscount!.ProductId).Sum(op => op.ProductCost);
                
            }
        }
        else if (discount.Type == DiscountType.Subscriber)
        {
            throw new NotImplementedException("Subscribe discount not implemented");
        }

        discountPrice = discount.AmountType == DiscountAmountType.Amount
            ? discount.DiscountAmount
            : ((totalPrice / 100) * discount.DiscountPercent);
        return discountPrice;
    }
}