﻿using NetinaShop.Domain.Dtos.SmallDtos;

namespace NetinaShop.Core.EntityServices.DiscountHandlers;

public class CalculateProductDiscountCommandHandler : IRequestHandler<CalculateProductDiscountCommand, ProductSDto>
{
    private readonly IRepositoryWrapper _repositoryWrapper;

    public CalculateProductDiscountCommandHandler(IRepositoryWrapper repositoryWrapper)
    {
        _repositoryWrapper = repositoryWrapper;
    }
    public async Task<ProductSDto> Handle(CalculateProductDiscountCommand request, CancellationToken cancellationToken)
    {
        double discountPrice = 0;
        request.ProductSDto.CostWithDiscount = request.ProductSDto.Cost;
        double totalPrice = request.ProductSDto.Cost;

        var allDiscount = await _repositoryWrapper.SetRepository<Discount>()
            .TableNoTracking
            .FirstOrDefaultAsync(d => d.Type == DiscountType.All && d.HasCode == false && d.ExpireDate.Date >= DateTime.Today.Date, cancellationToken);

        if (allDiscount != null && !allDiscount.IsExpired())
        {

            discountPrice = allDiscount.AmountType == DiscountAmountType.Amount ? totalPrice - allDiscount.DiscountAmount :
                totalPrice - totalPrice / 100 * allDiscount.DiscountPercent;
            request.ProductSDto.HasDiscount = true;
        }

        var categoryDiscount = await _repositoryWrapper.SetRepository<CategoryDiscount>()
        .TableNoTracking
        .FirstOrDefaultAsync(d => d.CategoryId == request.ProductSDto.CategoryId && d.HasCode == false && d.ExpireDate.Date >= DateTime.Today.Date, cancellationToken);

        if (categoryDiscount != null && !categoryDiscount.IsExpired())
        {
            discountPrice = categoryDiscount.AmountType == DiscountAmountType.Amount
            ? totalPrice - categoryDiscount.DiscountAmount : totalPrice - totalPrice / 100 * categoryDiscount.DiscountPercent;
            request.ProductSDto.HasDiscount = true;
        }

        var productDiscount = await _repositoryWrapper.SetRepository<ProductDiscount>()
        .TableNoTracking
        .Where(d => d.HasCode == false && d.ProductId == request.ProductSDto.Id && d.ExpireDate.Date >= DateTime.Today.Date)
        .OrderByDescending(d => d.CreatedAt)
        .FirstOrDefaultAsync(cancellationToken);

        if (productDiscount != null && !productDiscount.IsExpired())
        {
            discountPrice = productDiscount.AmountType == DiscountAmountType.Amount ? totalPrice - productDiscount.DiscountAmount
                : totalPrice - totalPrice / 100 * productDiscount.DiscountPercent;

            request.ProductSDto.HasDiscount = true;
            if (productDiscount.IsSpecialOffer)
                request.ProductSDto.IsSpecial = true;
        }

        if (request.ProductSDto.HasDiscount)
        {
            request.ProductSDto.CostWithDiscount = discountPrice;
            request.ProductSDto.DiscountPercent = request.ProductSDto.Cost == 0 ? 0 : 100 - 100 * request.ProductSDto.CostWithDiscount / request.ProductSDto.Cost;
        }

        return request.ProductSDto;
    }
}