﻿using Microsoft.EntityFrameworkCore;

namespace NetinaShop.Repository.Handlers.Products;

public class GetProductQueryHandler : IRequestHandler<GetProductQuery, GetProductResponseDto>
{
    private readonly IRepositoryWrapper _repositoryWrapper;

    public GetProductQueryHandler(IRepositoryWrapper repositoryWrapper)
    {
        _repositoryWrapper = repositoryWrapper;
    }
    public async Task<GetProductResponseDto> Handle(GetProductQuery request, CancellationToken cancellationToken)
    {
        var ent = await _repositoryWrapper.SetRepository<Product>().TableNoTracking
            .Where(b => b.Id == request.Id)
            .Select(ProductMapper.ProjectToLDto)
            .FirstOrDefaultAsync(cancellationToken);

        if (ent == null)
            throw new AppException("Product not found", ApiResultStatusCode.NotFound);

        var specialOffer = await _repositoryWrapper.SetRepository<ProductDiscount>()
            .TableNoTracking
            .Where(pd => pd.IsSpecialOffer && pd.ProductId == ent.Id)
            .Select(DiscountMapper.ProjectToSDto)
            .FirstOrDefaultAsync(cancellationToken);

        ent.SpecialOffer = specialOffer;

        if (ent.SpecialOffer == null || ent.SpecialOffer.ExpireDate.Date < DateTime.Today.Date)
            ent.IsSpecialOffer = false;
        else
            ent.IsSpecialOffer = true;

        var response = new GetProductResponseDto
        {
            Product = ent
        };
        return response;
    }
}